@@ -70,12 +70,16 @@ from html5lib import treewalkers, serializer
 text_content = etree.XPath("string()")
 
 
-def tostring(lxmltree, options=None, encoding='utf8'):
+def tostring(lxmltree, options=None):
     options = options or {'omit_optional_tags': False}
     walker = treewalkers.getTreeWalker('lxml')
     stream = walker(lxmltree)
     s = serializer.htmlserializer.HTMLSerializer(**options)
-    return s.render(stream, encoding)
+    output = s.render(stream)
+    if not isinstance(output, str):
+        # Python 2
+        output = output.encode('utf-8')
+    return output
 
 
 class Writer(writers.Writer):
@@ -256,7 +260,10 @@ class HTML5Translator(nodes.NodeVisitor):
     def encode(self, text):
         """Encode special characters in `text` & return."""
         # @@@ A codec to do these and all other HTML entities would be nice.
-        text = unicode(text)
+        try:
+            text = text.decode('utf-8')
+        except:
+            pass  # Text is probably already decoded, python 2/3 compat
         return text.translate({
             ord('&'): u'&amp;',
             ord('<'): u'&lt;',
@@ -638,6 +645,7 @@ simple_elements = {         # HTML equiv.
     "field_name": Tag("td", "field-name"),
     "figure": Tag("figure"),
     "image": Tag("img", attribute_map={"uri": "src", "alt": "alt"}),
+    "inline": Tag("span"),
     "list_item": Tag("li"),
     "literal": Tag("samp"),
     "literal_block": Tag("pre"),
